@@ -31,8 +31,8 @@
 #include <string>
 
 
-using SigC::bind;
-using SigC::slot;
+using sigc::bind;
+using sigc::mem_fun;
 
 class Window_DruidDemo : public Gtk::Window
 {
@@ -45,16 +45,11 @@ protected:
   //Signal handlers:
   virtual void On_Button_RunDruid();
   
-  //'virtual function' signal overrides:
-  virtual gint delete_event_impl(GdkEventAny*);
-  
 protected:
   Gtk::VBox m_VBox;
   Gtk::HBox m_HBox;
   Gtk::Button m_Button_RunDruid;
   Dialog_Druid m_Dialog;
-
-
 };
 
 #endif //HEADER_WINDOW_DRUIDDEMO
